@@ -383,6 +383,48 @@ def export_queries(queries_ids):
     }
 
 
+def get_associated_group_list():
+    """
+
+    Returns:
+        {
+            'IsSuccesfull': True,
+            'ErrorMessage': None,
+            'GroupList': [
+                {
+                    'FullPath': '/CxServer',
+                    'GroupName': 'CxServer',
+                    'Guid': '1',
+                    'ID': '1',
+                    'Path': None,
+                    'Type': 'Team'
+                }
+            ]
+        }
+    """
+    @retry_when_unauthorized
+    def execute():
+        client, factory = get_client_and_factory(relative_web_interface_url=relative_web_interface_url)
+        return client.service.GetAssociatedGroupsList(SessionID="0")
+
+    response = execute()
+    group_list = response.GroupList
+    return {
+        "IsSuccesfull": response["IsSuccesfull"],
+        "ErrorMessage": response["ErrorMessage"],
+        "GroupList": [
+            {
+                "FullPath": item["FullPath"],
+                "GroupName": item["GroupName"],
+                "Guid": item["Guid"],
+                "ID": item["ID"],
+                "Path": item["Path"],
+                "Type": item["Type"],
+            } for item in group_list.Group
+        ] if group_list else None
+    }
+
+
 def get_compare_scan_results(old_scan_id, new_scan_id):
     """
 
@@ -545,57 +587,64 @@ def get_query_collection():
         return client.service.GetQueryCollection(sessionId="0")
 
     response = execute()
+    query_groups = []
+    for query_group in response.QueryGroups.CxWSQueryGroup:
+        if query_group.Queries:
+            queries = [
+                {
+                    "Categories": [
+                        {
+                            "CategoryName": category.CategoryName,
+                            "CategoryType": {
+                                "Id": category.CategoryType.Id,
+                                "Name": category.CategoryType.Name,
+                                "Order": category.CategoryType.Order,
+                            },
+                            "Id": category.Id
+                        } for category in query.Categories.CxQueryCategory
+                    ] if query.Categories else query.Categories,
+                    "Cwe": query.Cwe,
+                    "CxDescriptionID": query.CxDescriptionID,
+                    "EngineMetadata": query.EngineMetadata,
+                    "IsEncrypted": query.IsEncrypted,
+                    "IsExecutable": query.IsExecutable,
+                    "Name": query.Name,
+                    "PackageId": query.PackageId,
+                    "QueryId": query.QueryId,
+                    "QueryVersionCode": query.QueryVersionCode,
+                    "Severity": query.Severity,
+                    "Source": query.Source,
+                    "Status": query.Status,
+                    "Type": query.Type,
+                } for query in query_group.Queries.CxWSQuery
+            ]
+        else:
+            queries = []
+        qg = {
+            "Description": query_group.Description,
+            "Impacts": query_group.Impacts,
+            "IsEncrypted": query_group.IsEncrypted,
+            "IsReadOnly": query_group.IsReadOnly,
+            "Language": query_group.Language,
+            "LanguageName": query_group.LanguageName,
+            "LanguageStateDate": query_group.LanguageStateDate,
+            "LanguageStateHash": query_group.LanguageStateHash,
+            "Name": query_group.Name,
+            "OwningTeam": query_group.OwningTeam,
+            "PackageFullName": query_group.PackageFullName,
+            "PackageId": query_group.PackageId,
+            "PackageType": query_group.PackageType,
+            "PackageTypeName": query_group.PackageTypeName,
+            "ProjectId": query_group.ProjectId,
+            "Queries": queries,
+            "Status": query_group.Status
+        }
+
+        query_groups.append(qg)
     return {
         "IsSuccesfull": response.IsSuccesfull,
         "ErrorMessage": response.ErrorMessage,
-        "QueryGroups": [
-            {
-                "Description": query_group.Description,
-                "Impacts": query_group.Impacts,
-                "IsEncrypted": query_group.IsEncrypted,
-                "IsReadOnly": query_group.IsReadOnly,
-                "Language": query_group.Language,
-                "LanguageName": query_group.LanguageName,
-                "LanguageStateDate": query_group.LanguageStateDate,
-                "LanguageStateHash": query_group.LanguageStateHash,
-                "Name": query_group.Name,
-                "OwningTeam": query_group.OwningTeam,
-                "PackageFullName": query_group.PackageFullName,
-                "PackageId": query_group.PackageId,
-                "PackageType": query_group.PackageType,
-                "PackageTypeName": query_group.PackageTypeName,
-                "ProjectId": query_group.ProjectId,
-                "Queries": [
-                    {
-                        "Categories": [
-                            {
-                                "CategoryName": category.CategoryName,
-                                "CategoryType": {
-                                    "Id": category.CategoryType.Id,
-                                    "Name": category.CategoryType.Name,
-                                    "Order": category.CategoryType.Order,
-                                },
-                                "Id": category.Id
-                            } for category in query.Categories.CxQueryCategory
-                        ] if query.Categories else query.Categories,
-                        "Cwe": query.Cwe,
-                        "CxDescriptionID": query.CxDescriptionID,
-                        "EngineMetadata": query.EngineMetadata,
-                        "IsEncrypted": query.IsEncrypted,
-                        "IsExecutable": query.IsExecutable,
-                        "Name": query.Name,
-                        "PackageId": query.PackageId,
-                        "QueryId": query.QueryId,
-                        "QueryVersionCode": query.QueryVersionCode,
-                        "Severity": query.Severity,
-                        "Source": query.Source,
-                        "Status": query.Status,
-                        "Type": query.Type,
-                    } for query in query_group.Queries.CxWSQuery
-                ],
-                "Status": query_group.Status
-            } for query_group in response.QueryGroups.CxWSQueryGroup
-        ]
+        "QueryGroups": query_groups
     }
 
 
@@ -626,7 +675,6 @@ def get_query_id_by_language_group_and_query_name(
         query_collection = [item for item in query_collection if item.get("LanguageName") in language]
 
     if isinstance(package_type_name, str):
-        assert package_type_name in ["Cx", "Corp"]
         query_collection = [item for item in query_collection if item.get("PackageTypeName") == package_type_name]
     elif isinstance(package_type_name, (list, tuple)):
         query_collection = [item for item in query_collection if item.get("PackageTypeName") in package_type_name]
@@ -703,6 +751,71 @@ def get_preset_list():
     }
 
 
+def get_projects_display_data():
+    """
+
+    Returns:
+    {
+        "IsSuccesfull": True,
+        "ErrorMessage": None,
+        "ProjectList": [
+            {
+                'Company': None,
+                'Group': 'CxServer',
+                'IsPublic': True,
+                'LastScanDate': {
+                        'Hour': 10,
+                        'Minute': 5,
+                        'Second': 2,
+                        'Day': 23,
+                        'Month': 9,
+                        'Year': 2022
+                    },
+                'Owner': 'Admin',
+                'Permission': {
+                    'IsAllowedToDelete': True,
+                    'IsAllowedToDuplicate': True,
+                    'IsAllowedToRun': True,
+                    'IsAllowedToUpdate': True
+                },
+                'Preset': 'Checkmarx Default',
+                'ProjectName': 'jvl_git',
+                'ServiceProvider': None,
+                'TotalOsaScans': 0,
+                'TotalScans': 41,
+                'projectID': 5
+            }
+        ]
+    """
+    @retry_when_unauthorized
+    def execute():
+        client, factory = get_client_and_factory(relative_web_interface_url=relative_web_interface_url)
+        return client.service.GetProjectsDisplayData(sessionID="0")
+
+    response = execute()
+    project_list = response.projectList
+    return {
+        "IsSuccesfull": response["IsSuccesfull"],
+        "ErrorMessage": response["ErrorMessage"],
+        "ProjectList": [
+            {
+                "Company": item["Company"],
+                "Group": item["Group"],
+                "IsPublic": item["IsPublic"],
+                "LastScanDate": item["LastScanDate"],
+                "Owner": item["Owner"],
+                "Permission": item["Permission"],
+                "Preset": item["Preset"],
+                "ProjectName": item["ProjectName"],
+                "ServiceProvider": item["ServiceProvider"],
+                "TotalOsaScans": item["TotalOsaScans"],
+                "TotalScans": item["TotalScans"],
+                "projectID": item["projectID"],
+            } for item in project_list.ProjectDisplayData
+        ] if project_list else None
+    }
+
+
 def get_result_path(scan_id, path_id):
     """
 
@@ -1006,6 +1119,28 @@ def lock_scan(scan_id):
     }
 
 
+def postpone_scan(scan_id):
+    """
+
+    Args:
+        scan_id (int):
+
+    Returns:
+
+    """
+
+    @retry_when_unauthorized
+    def execute():
+        client, factory = get_client_and_factory(relative_web_interface_url=relative_web_interface_url)
+        return client.service.PostponeScan(sessionID="0", RunId=str(scan_id))
+
+    response = execute()
+    return {
+        "IsSuccesfull": response["IsSuccesfull"],
+        "ErrorMessage": response["ErrorMessage"],
+    }
+
+
 def unlock_scan(scan_id):
     """
 
